@@ -44,7 +44,6 @@
 #include <KToolBar>
 #include <KParts/ReadOnlyPart>
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KXMLGUIFactory>
 #include <KLocalizedString>
 
@@ -67,19 +66,19 @@ using namespace Massif;
 // Helper function
 static KConfigGroup allocatorConfig()
 {
-    return KSharedConfig::openConfig()->group("Allocators");
+    return KSharedConfig::openConfig()->group(QStringLiteral("Allocators"));
 }
 
 MainWindow::MainWindow(QWidget* parent, Qt::WindowFlags f)
     : KParts::MainWindow(parent, f)
-    , m_recentFiles(0)
-    , m_close(0)
+    , m_recentFiles(nullptr)
+    , m_close(nullptr)
     , m_allocatorModel(new QStringListModel(this))
-    , m_newAllocator(0)
-    , m_removeAllocator(0)
-    , m_shortenTemplates(0)
-    , m_selectPeak(0)
-    , m_currentDocument(0)
+    , m_newAllocator(nullptr)
+    , m_removeAllocator(nullptr)
+    , m_shortenTemplates(nullptr)
+    , m_selectPeak(nullptr)
+    , m_currentDocument(nullptr)
     , m_dataTreeModel(new DataTreeModel(this))
     , m_dataTreeFilterModel(new FilteredDataTreeModel(m_dataTreeModel))
     , m_settingSelection(false)
@@ -92,9 +91,9 @@ MainWindow::MainWindow(QWidget* parent, Qt::WindowFlags f)
     // NOTE: just check if kgraphviewer is available at runtime.
     // The former logic has been moved to DocumentWidget constructor.
 #ifdef HAVE_KGRAPHVIEWER
-    KPluginFactory *factory = KPluginLoader(QStringLiteral("kgraphviewerpart")).factory();
+    KPluginFactory *factory = KPluginFactory::loadFactory(KPluginMetaData(QStringLiteral("kf6/parts/kgraphviewerpart"))).plugin;
     if (factory) {
-        KParts::ReadOnlyPart* readOnlyPart = factory->create<KParts::ReadOnlyPart>(QString(), this);
+        KParts::ReadOnlyPart* readOnlyPart = factory->create<KParts::ReadOnlyPart>(this);
         if (readOnlyPart) {
             readOnlyPart->widget()->hide();
             haveGraphViewer = true;
@@ -171,47 +170,47 @@ MainWindow::~MainWindow()
 
 void MainWindow::setupActions()
 {
-    QAction* openFile = KStandardAction::open(this, SLOT(openFile()), actionCollection());
-    m_recentFiles = KStandardAction::openRecent(this, SLOT(openFile(QUrl)), actionCollection());
+    QAction* openFile = KStandardAction::open(this, qOverload<>(&MainWindow::openFile), actionCollection());
+    m_recentFiles = KStandardAction::openRecent(this, qOverload<const QUrl &>(&MainWindow::openFile), actionCollection());
     m_recentFiles->loadEntries(KSharedConfig::openConfig()->group( QString() ));
 
-    QAction* reload = KStandardAction::redisplay(this, SLOT(reloadCurrentFile()), actionCollection());
+    QAction* reload = KStandardAction::redisplay(this, &MainWindow::reloadCurrentFile, actionCollection());
     actionCollection()->addAction(QStringLiteral("file_reload"), reload);
     reload->setEnabled(false);
 
-    m_close = KStandardAction::close(this, SLOT(closeCurrentFile()), actionCollection());
+    m_close = KStandardAction::close(this, &MainWindow::closeCurrentFile, actionCollection());
     m_close->setEnabled(false);
 
-    KStandardAction::quit(qApp, SLOT(closeAllWindows()), actionCollection());
+    KStandardAction::quit(qApp, QApplication::closeAllWindows, actionCollection());
 
-    KStandardAction::preferences(this, SLOT(preferences()), actionCollection());
+    KStandardAction::preferences(this, &MainWindow::preferences, actionCollection());
 
-    m_shortenTemplates = new QAction(QIcon::fromTheme(QStringLiteral("shortentemplates")), i18n("Shorten Templates"), actionCollection());
+    m_shortenTemplates = new QAction(QIcon::fromTheme(QStringLiteral("shortentemplates")), i18nc("@action", "Shorten Templates"), actionCollection());
     m_shortenTemplates->setCheckable(true);
     m_shortenTemplates->setChecked(Settings::shortenTemplates());
     connect(m_shortenTemplates, &QAction::toggled, this, &MainWindow::slotShortenTemplates);
     actionCollection()->addAction(QStringLiteral("shorten_templates"), m_shortenTemplates);
 
-    m_selectPeak = new QAction(QIcon::fromTheme(QStringLiteral("flag-red")), i18n("Select peak snapshot"), actionCollection());
+    m_selectPeak = new QAction(QIcon::fromTheme(QStringLiteral("flag-red")), i18nc("@action", "Select Peak Snapshot"), actionCollection());
     connect(m_selectPeak, &QAction::triggered, this, &MainWindow::selectPeakSnapshot);
     actionCollection()->addAction(QStringLiteral("selectPeak"), m_selectPeak);
     m_selectPeak->setEnabled(false);
 
     //BEGIN custom allocators
-    m_newAllocator = new QAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("add"), ui.allocatorDock);
-    m_newAllocator->setToolTip(i18n("add custom allocator"));
+    m_newAllocator = new QAction(QIcon::fromTheme(QStringLiteral("list-add")), i18nc("@action", "Add"), ui.allocatorDock);
+    m_newAllocator->setToolTip(i18nc("@info:tooltip", "Add custom allocator"));
     connect(m_newAllocator, &QAction::triggered, this, &MainWindow::slotNewAllocator);
     ui.dockMenuBar->addAction(m_newAllocator);
-    m_removeAllocator = new QAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18n("remove"),
+    m_removeAllocator = new QAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18nc("@action", "Remove"),
                                     ui.allocatorDock);
-    m_newAllocator->setToolTip(i18n("remove selected allocator"));
+    m_newAllocator->setToolTip(i18nc("@info:tooltip", "Remove selected allocator"));
     connect(m_removeAllocator, &QAction::triggered, this, &MainWindow::slotRemoveAllocator);
     connect(ui.allocatorView->selectionModel(), &QItemSelectionModel::selectionChanged,
             this, &MainWindow::allocatorSelectionChanged);
     m_removeAllocator->setEnabled(false);
     ui.dockMenuBar->addAction(m_removeAllocator);
 
-    m_markCustomAllocator = new QAction(i18n("mark as custom allocator"), ui.allocatorDock);
+    m_markCustomAllocator = new QAction(i18nc("@action", "Mark as Custom Allocator"), ui.allocatorDock);
     connect(m_markCustomAllocator, &QAction::triggered,
             this, &MainWindow::slotMarkCustomAllocator, Qt::QueuedConnection);
     //END custom allocators
@@ -222,7 +221,7 @@ void MainWindow::setupActions()
 
     //open page actions
     ui.openFile->setDefaultAction(openFile);
-    ui.openFile->setText(i18n("Open Massif Data File"));
+    ui.openFile->setText(i18nc("@action:button", "Open Massif Data File"));
     ui.openFile->setIconSize(QSize(48, 48));
 }
 
@@ -254,7 +253,8 @@ void MainWindow::settingsChanged()
 
 void MainWindow::openFile()
 {
-    const QList<QUrl> files = QFileDialog::getOpenFileUrls(this, i18n("Open Massif Output File"), QUrl(),
+    const QList<QUrl> files = QFileDialog::getOpenFileUrls(this, i18nc("@title:window", "Open Massif Output File"),
+                                                           QUrl(),
                                                            i18n("Massif data files (massif.out.*)"));
     foreach (const QUrl& file, files) {
         openFile(file);
@@ -392,7 +392,7 @@ void MainWindow::allocatorSelectionChanged()
 
 void MainWindow::slotNewAllocator()
 {
-    QString allocator = QInputDialog::getText(this, i18n("Add Custom Allocator"), i18n("allocator:"));
+    QString allocator = QInputDialog::getText(this, i18nc("@title:window", "Add Custom Allocator"), i18nc("@label:textbox", "Allocator:"));
     if (allocator.isEmpty()) {
         return;
     }
@@ -440,7 +440,7 @@ void MainWindow::dataTreeContextMenuRequested(const QPoint& pos)
     }
 
     QMenu menu;
-    contextMenuRequested(ModelItem(item, 0), &menu);
+    contextMenuRequested(ModelItem(item, nullptr), &menu);
 
     menu.exec(ui.dataTreeView->mapToGlobal(pos));
 }
@@ -476,7 +476,7 @@ void MainWindow::slotShortenTemplates(bool shorten)
 void MainWindow::updateWindowTitle()
 {
     if (m_currentDocument && m_currentDocument->isLoaded()) {
-        setWindowTitle(i18n("Evaluation of %1 (%2)", m_currentDocument->data()->cmd(), m_currentDocument->file().fileName()));
+        setWindowTitle(i18nc("@title:window", "Evaluation of %1 (%2)", m_currentDocument->data()->cmd(), m_currentDocument->file().fileName()));
     } else {
         setWindowTitle(QString());
     }
@@ -489,7 +489,7 @@ void MainWindow::documentChanged()
     setUpdatesEnabled(false);
 
     if (m_currentDocument) {
-        m_dataTreeModel->setSource(0);
+        m_dataTreeModel->setSource(nullptr);
         m_dataTreeFilterModel->setFilter(QString());
         m_currentDocument->clearGuiActions(guiFactory());
         disconnect(m_currentDocument, &DocumentWidget::modelItemSelected,
@@ -521,3 +521,5 @@ void MainWindow::documentChanged()
 
     setUpdatesEnabled(true);
 }
+
+#include "moc_mainwindow.cpp"
