@@ -23,8 +23,8 @@
 #ifndef MASSIF_FILEDATA_H
 #define MASSIF_FILEDATA_H
 
-#include <QtCore/QObject>
-#include <QtCore/QVector>
+#include <QObject>
+#include <QList>
 
 namespace Massif {
 
@@ -37,8 +37,8 @@ class FileData : public QObject
 {
     Q_OBJECT
 public:
-    FileData(QObject* parent = 0);
-    virtual ~FileData();
+    explicit FileData(QObject* parent = nullptr);
+    ~FileData() override;
 
     /**
      * Set the @p cmd that was profiled with massif.
@@ -74,7 +74,7 @@ public:
     /**
      * @return List of all snapshots that make up this dataset.
      */
-    QVector<SnapshotItem*> snapshots() const;
+    QList<SnapshotItem*> snapshots() const;
 
     /**
      * Marks @p snapshot as peak of this dataset.
@@ -90,7 +90,7 @@ private:
     QString m_cmd;
     QString m_description;
     QString m_timeUnit;
-    QVector<SnapshotItem*> m_snapshots;
+    QList<SnapshotItem*> m_snapshots;
     SnapshotItem* m_peak;
 };
 
