@@ -31,12 +31,12 @@
 #include "KChartDataValueAttributes"
 #include "KChartLineAttributes"
 
-#include <QtGui/QColor>
-#include <QtGui/QPen>
-#include <QtGui/QBrush>
+#include <QColor>
+#include <QPen>
+#include <QBrush>
 
-#include <QtCore/QMultiMap>
-#include <QtCore/qalgorithms.h>
+#include <QMultiMap>
+#include <algorithm>
 
 #include <KLocalizedString>
 
@@ -57,7 +57,7 @@ QVariant colorForColumn(int column, int columnCount, int role)
 }
 
 DetailedCostModel::DetailedCostModel(QObject* parent)
-    : QAbstractTableModel(parent), m_data(0), m_maxDatasetCount(10)
+    : QAbstractTableModel(parent), m_data(nullptr), m_maxDatasetCount(10)
 {
 }
 
@@ -69,7 +69,7 @@ void DetailedCostModel::setSource(const FileData* data)
 {
     if (m_data) {
         beginRemoveRows(QModelIndex(), 0, rowCount() - 1);
-        m_data = 0;
+        m_data = nullptr;
         m_columns.clear();
         m_rows.clear();
         m_nodes.clear();
@@ -82,7 +82,7 @@ void DetailedCostModel::setSource(const FileData* data)
         QMultiMap<int, QByteArray> sortColumnMap;
         foreach (const SnapshotItem* snapshot, data->snapshots()) {
             if (snapshot->heapTree()) {
-                QVector<const TreeLeafItem*> nodes;
+                QList<const TreeLeafItem*> nodes;
                 foreach (const TreeLeafItem* node, snapshot->heapTree()->children()) {
                     if (isBelowThreshold(node->label())) {
                         continue;
@@ -118,7 +118,7 @@ void DetailedCostModel::setSource(const FileData* data)
         }
         // ugh, yet another bad usage of QList in Qt's API
         m_columns = sortColumnMap.values().toVector();
-        QAlgorithmsPrivate::qReverse(m_columns.begin(), m_columns.end());
+        std::reverse(m_columns.begin(), m_columns.end());
 
         if (m_rows.isEmpty()) {
             return;
@@ -197,7 +197,7 @@ QVariant DetailedCostModel::data(const QModelIndex& index, int role) const
         } else {
             if (index.column() % 2 == 0) {
                 // get x-coordinate of the last snapshot with cost below 0.1% of peak cost
-                QVector< SnapshotItem* >::const_iterator it = m_data->snapshots().constBegin();
+                QList< SnapshotItem* >::const_iterator it = m_data->snapshots().constBegin();
                 double time = 0;
                 while (it != m_data->snapshots().constEnd() && (*it)->cost() < m_data->peak()->cost() * 0.001) {
                     time = (*it)->time();
@@ -224,7 +224,7 @@ QVariant DetailedCostModel::data(const QModelIndex& index, int role) const
     if (index.column() % 2 == 0 && role != Qt::ToolTipRole) {
         return snapshot->time();
     } else {
-        const TreeLeafItem* node = 0;
+        const TreeLeafItem* node = nullptr;
         const QByteArray needle = m_columns.at(index.column() / 2);
         foreach(const TreeLeafItem* n, m_nodes[snapshot]) {
             if (n->label() == needle) {
@@ -334,21 +334,21 @@ QModelIndex DetailedCostModel::indexForTreeLeaf(const TreeLeafItem* node) const
 ModelItem DetailedCostModel::itemForIndex(const QModelIndex& idx) const
 {
     if (!idx.isValid() || idx.parent().isValid() || idx.row() > rowCount() || idx.column() > columnCount()) {
-        return ModelItem(0, 0);
+        return ModelItem(nullptr, nullptr);
     }
     if (idx.row() == 0) {
-        return ModelItem(0, 0);
+        return ModelItem(nullptr, nullptr);
     }
     const QByteArray needle = m_columns.at(idx.column() / 2);
     for (int i = 1; i < 3 && idx.row() - i >= 0; ++i) {
         const SnapshotItem* snapshot = m_rows.at(idx.row() - i);
         foreach(const TreeLeafItem* n, m_nodes[snapshot]) {
             if (n->label() == needle) {
-                return ModelItem(n, 0);
+                return ModelItem(n, nullptr);
             }
         }
     }
-    return ModelItem(0, 0);
+    return ModelItem(nullptr, nullptr);
 }
 
 QModelIndex DetailedCostModel::indexForItem(const ModelItem& item) const
@@ -374,7 +374,7 @@ void DetailedCostModel::hideFunction(const TreeLeafItem* node)
     beginResetModel();
     Nodes::iterator it = m_nodes.begin();
     while (it != m_nodes.end()) {
-        QVector< const TreeLeafItem* >::iterator it2 = it.value().begin();
+        QList< const TreeLeafItem* >::iterator it2 = it.value().begin();
         while (it2 != it.value().end()) {
             if ((*it2)->label() == node->label()) {
                 it2 = it.value().erase(it2);
@@ -400,7 +400,7 @@ void DetailedCostModel::hideOtherFunctions(const TreeLeafItem* node)
     Nodes::iterator it = m_nodes.begin();
     const Nodes::iterator end = m_nodes.end();
     while (it != end) {
-        QVector< const TreeLeafItem* >::iterator it2 = it.value().begin();
+        QList< const TreeLeafItem* >::iterator it2 = it.value().begin();
         while (it2 != it.value().end()) {
             if ((*it2)->label() != node->label()) {
                 it2 = it.value().erase(it2);
